@@ -560,42 +560,32 @@ var app = window.Yancy = new Vue({
                     continue;
                 }
 
-                if ( !definition[ 'x-list-columns' ] ) {
-                    var seen = {}; // keep track of columns seen in list
-                    definition[ 'x-list-columns' ] = [
-                        definition[ 'x-id-field' ] || 'id', 'name', 'username', 'title', 'slug'
-                    ].filter( function (x) {
-                        if ( !seen[x] ) { seen[x] = 0 }
-                        // do not allow duplicate columns, if for
-                        // example the `x-id-field` is "name" or "username"
-                        return !seen[x]++ && definition.properties[x];
-                    } );
-                    // Show a warning to the user if we think this
-                    // guessed value for x-list-columns is kind of
-                    // useless (a non-string field is probably not
-                    // useful as a human identifier)
-                    // XXX: We could write better heuristics for
-                    // listable columns by finding the first 5-6 columns
-                    // (by x-order) that aren't textarea strings or
-                    // markdown strings.
-                    // Or, we could add CSS to prevent long strings from
-                    // breaking the table ("white-space: nowrap;
-                    // text-overflow: ellipsis" would show only the
-                    // first part of the first line of a large block of
-                    // text.
-                    if ( definition[ 'x-list-columns' ].length == 1
-                        && definition.properties[ definition[ 'x-list-columns' ][0] ].type != 'string'
-                    ) {
-                        definition[ 'x-list-columns-guessed' ] = true;
-                    }
-                }
-
+                // Hide any HTML columns linked to Markdown columns
                 for ( var propKey in definition.properties ) {
                     var prop = definition.properties[ propKey ];
                     if ( prop[ 'x-html-field' ] && definition.properties[ prop['x-html-field'] ] ) {
                         definition.properties[ prop['x-html-field' ] ][ 'x-hidden' ] = true;
                     }
                 }
+
+                // Create some kind of column list
+                if ( !definition[ 'x-list-columns' ] && definition.properties ) {
+                    definition[ 'x-list-columns' ] = Object.keys( definition.properties ).filter(
+                        function (x) {
+                            var prop = definition.properties[x];
+                            if ( prop['x-hidden'] ) { return; }
+                            // Do not allow binary or base64 (byte) fields
+                            if ( prop.format ) {
+                                return prop.format != "binary" && prop.format != "byte";
+                            }
+                            return true;
+                        }
+                    ).sort( function (a, b) {
+                        return definition.properties[a]['x-order'] - definition.properties[b]['x-order']
+                            || ( a > b ? 1 : a < b ? -1 : 0 );
+                    } );
+                }
+
             }
 
             for ( var pathKey in spec.paths ) {
@@ -961,14 +951,19 @@ var app = window.Yancy = new Vue({
             var self = this;
             this.toasts.push( toast );
             setTimeout(
-                function ( toast ) { self.removeToast( toast ) },
+                function ( toast ) { self.removeToast( null, toast ) },
                 5000,
                 toast
             );
         },
 
-        removeToast: function ( toast ) {
-            this.toasts.splice( this.toasts.indexOf( toast ), 1 );
+        removeToast: function ( event, toast ) {
+            var target = event ? $( event.target ).closest( '.toast' ) : $( '.toast-container .toast' ).first(),
+                self = this;
+            target.on( 'hidden.bs.toast', function () {
+                self.toasts.splice( self.toasts.indexOf( toast ), 1 );
+            } );
+            target.toast( 'hide' );
         }
 
     },
