@@ -1,5 +1,5 @@
 package Yancy::Backend::Dbic;
-our $VERSION = '1.063';
+our $VERSION = '1.064';
 # ABSTRACT: A backend for DBIx::Class schemas
 
 #pod =head1 SYNOPSIS
@@ -402,6 +402,9 @@ sub _map_type {
     elsif ( $db_type =~ /^(?:timestamp|datetime)/i ) {
         %conf = ( %conf, type => 'string', format => 'date-time' );
     }
+    elsif ( $db_type =~ /(?:blob|bytea)/i ) {
+        %conf = ( %conf, type => 'string', format => 'binary' );
+    }
     else {
         # Default to string
         %conf = ( %conf, type => 'string' );
@@ -432,7 +435,7 @@ Yancy::Backend::Dbic - A backend for DBIx::Class schemas
 
 =head1 VERSION
 
-version 1.063
+version 1.064
 
 =head1 SYNOPSIS
 
